@@ -5,11 +5,11 @@
 #' `dl_stats19()` and `read_*` functions, returning a
 #' `tibble` (default), `data.frame`, `sf` or `ppp` object, depending on the
 #' `output_format` parameter.
-#' The function returns data for a specific year (e.g. `year = 2017`)
+#' The function returns data for a specific year (e.g. `year = 2022`)
 #'
 #' Note: for years before 2016 the function may return data from more years than are
 #' requested due to the nature of the files hosted at
-#' [data.gov.uk](https://data.gov.uk/dataset/cb7ae6f0-4be6-4935-9277-47e5ce24a11f/road-safety-data).
+#' [data.gov.uk](https://www.data.gov.uk/dataset/cb7ae6f0-4be6-4935-9277-47e5ce24a11f/road-safety-data).
 #'
 #' As this function uses `dl_stats19` function, it can download many MB of data,
 #' so ensure you have a sufficient disk space.
@@ -20,7 +20,7 @@
 #' functions, as shown in the examples.
 #'
 #' @seealso [dl_stats19()]
-#' @seealso [read_accidents()]
+#' @seealso [read_collisions()]
 #'
 #' @inheritParams dl_stats19
 #' @param format Switch to return raw read from file, default is `TRUE`.
@@ -36,28 +36,25 @@
 #' @examples
 #' \donttest{
 #' if(curl::has_internet()) {
-#' # default tibble output
-#' x = get_stats19(2019)
+#' x = get_stats19(2022, silent = TRUE, format = TRUE)
 #' class(x)
-#' x = get_stats19(2017, silent = TRUE)
-#'
 #' # data.frame output
-#' x = get_stats19(2017, silent = TRUE, output_format = "data.frame")
+#' x = get_stats19(2022, silent = TRUE, output_format = "data.frame")
 #' class(x)
 #'
 #' # Run tests only if endpoint is alive:
 #' if(nrow(x) > 0) {
 #'
 #' # sf output
-#' x_sf = get_stats19(2017, silent = TRUE, output_format = "sf")
+#' x_sf = get_stats19(2022, silent = TRUE, output_format = "sf")
 #'
 #' # sf output with lonlat coordinates
-#' x_sf = get_stats19(2017, silent = TRUE, output_format = "sf", lonlat = TRUE)
+#' x_sf = get_stats19(2022, silent = TRUE, output_format = "sf", lonlat = TRUE)
 #' sf::st_crs(x_sf)
 #'
 #' if (requireNamespace("spatstat.geom", quietly = TRUE)) {
 #' # ppp output
-#' x_ppp = get_stats19(2017, silent = TRUE, output_format = "ppp")
+#' x_ppp = get_stats19(2022, silent = TRUE, output_format = "ppp")
 #'
 #' # We can use the window parameter of format_ppp function to filter only the
 #' # events occurred in a specific area. For example we can create a new bbox
@@ -68,7 +65,7 @@
 #' yrange = c(428577.2, 438577.2)
 #' )
 #'
-#' leeds_ppp = get_stats19(2017, silent = TRUE, output_format = "ppp", window = leeds_window)
+#' leeds_ppp = get_stats19(2022, silent = TRUE, output_format = "ppp", window = leeds_window)
 #' spatstat.geom::plot.ppp(leeds_ppp, use.marks = FALSE, clipwin = leeds_window)
 #'
 #' # or even more fancy examples where we subset all the events occurred in a
@@ -85,14 +82,14 @@
 #' # greater_london_polygon = sf::st_coordinates(greater_london_sf_polygon)[, c(1, 2)]
 #' # greater_london_window = spatstat.geom::owin(poly = greater_london_polygon)
 #'
-#' # greater_london_ppp = get_stats19(2017, output_format = "ppp", window = greater_london_window)
+#' # greater_london_ppp = get_stats19(2022, output_format = "ppp", window = greater_london_window)
 #' # spatstat.geom::plot.ppp(greater_london_ppp, use.marks = FALSE, clipwin = greater_london_window)
 #' }
 #' }
 #' }
 #' }
 get_stats19 = function(year = NULL,
-                      type = "accident",
+                      type = "collision",
                       data_dir = get_data_directory(),
                       file_name = NULL,
                       format = TRUE,
@@ -100,7 +97,6 @@ get_stats19 = function(year = NULL,
                       silent = FALSE,
                       output_format = "tibble",
                       ...) {
-  # browser()
   if(!exists("type")) {
     stop("Type is required", call. = FALSE)
   }
@@ -144,8 +140,8 @@ get_stats19 = function(year = NULL,
       year = year,
       data_dir = data_dir,
       format = format)
-  } else { # inline with type = "accident" by default
-    read_in = read_accidents(
+  } else { # inline with type = "collision" by default
+    read_in = read_collisions(
       year = year,
       data_dir = data_dir,
       format = format,
